@@ -241,6 +241,17 @@ var BuiltinFuncSignatures = map[string][]*FuncSignature{
 		Ret:    BoolType{},
 		Params: []ExprType{},
 	}},
+	"case": {{
+		Name: "case",
+		Ret:  AnyType{},
+		Params: []ExprType{
+			BoolType{},
+			AnyType{},
+			AnyType{},
+		},
+		VariableLengthParams: true,
+		IsConstFunc:          true,
+	}},
 }
 
 // Global variables
@@ -885,6 +896,10 @@ func (sema *ExprSemanticsChecker) checkBuiltinFuncCall(n *FuncCallNode, sig *Fun
 		if s, ok := err.(*json.SyntaxError); ok {
 			sema.errorf(lit, "broken JSON string is passed to fromJSON() at offset %d: %s", s.Offset, s)
 		}
+	case "case":
+		if len(n.Args)%2 == 0 {
+			sema.errorf(n, "case() requires an odd number of arguments (pred/value pairs + default) but got %d", len(n.Args))
+		}
 	}
 
 	return sig.Ret
