@@ -738,6 +738,46 @@ func TestExprSemanticsCheckOK(t *testing.T) {
 				"piyo": NullType{},
 			}),
 		},
+		{
+			what:     "case() with single predicate",
+			input:    "case(true, 'a', 'b')",
+			expected: AnyType{},
+		},
+		{
+			what:     "case() with multiple predicates",
+			input:    "case(true, 1, false, 2, 3)",
+			expected: AnyType{},
+		},
+		{
+			what:     "case() with number predicate (coerced to bool)",
+			input:    "case(1, 'a', 'b')",
+			expected: AnyType{},
+		},
+		{
+			what:     "case() with string predicate (coerced to bool)",
+			input:    "case('yes', 'a', 'b')",
+			expected: AnyType{},
+		},
+		{
+			what:     "case() with null predicate (coerced to bool)",
+			input:    "case(null, 'a', 'b')",
+			expected: AnyType{},
+		},
+		{
+			what:     "case() case insensitivity",
+			input:    "CASE(true, 1, 2)",
+			expected: AnyType{},
+		},
+		{
+			what:     "case() with expression as predicate",
+			input:    "case(startsWith('hello', 'he'), 'yes', 'no')",
+			expected: AnyType{},
+		},
+		{
+			what:     "case() with many predicates",
+			input:    "case(false, 'a', false, 'b', false, 'c', true, 'd', 'default')",
+			expected: AnyType{},
+		},
 	}
 
 	allSPFuncs := []string{}
@@ -1280,6 +1320,23 @@ func TestExprSemanticsCheckError(t *testing.T) {
 				"broken JSON string is passed to fromJSON() at offset 12",
 			},
 		},
+		{
+			what:  "case() with too few arguments",
+			input: "case() || case(true) || case(true, 'a')",
+			expected: []string{
+				"at least 3 parameters but 0 arguments are given",
+				"at least 3 parameters but 1 arguments are given",
+				"at least 3 parameters but 2 arguments are given",
+			},
+		},
+		{
+			what:  "case() with even number of arguments",
+			input: "case(true, 'a', false, 'b') || case(true, 'a', false, 'b', true, 'c')",
+			expected: []string{
+				"case() requires an odd number of arguments (pred/value pairs + default) but got 4",
+				"case() requires an odd number of arguments (pred/value pairs + default) but got 6",
+			},
+		},
 	}
 
 	allSP := []string{}
