@@ -54,15 +54,17 @@ func TestValidateGlobOK(t *testing.T) {
 		"*feature",
 		"v2*",
 		"v[12].[0-9]+.[0-9]+",
+		".foo.txt",
+		"..foo.txt",
 	}
 
 	for _, input := range testCases {
 		t.Run(input, func(t *testing.T) {
 			if errs := ValidateRefGlob(input); len(errs) > 0 {
-				t.Errorf("ref glob %q caused errors: %#v", input, errs)
+				t.Errorf("ref glob %q caused %d errors: %v", input, len(errs), errs)
 			}
 			if errs := ValidatePathGlob(input); len(errs) > 0 {
-				t.Errorf("path glob %q caused errors: %#v", input, errs)
+				t.Errorf("path glob %q caused %d errors: %v", input, len(errs), errs)
 			}
 		})
 	}
@@ -70,7 +72,6 @@ func TestValidateGlobOK(t *testing.T) {
 
 func TestValidateGlobPathOnlyOK(t *testing.T) {
 	testCases := []string{
-		".",
 		"/foo",
 		"/foo/",
 		"/foo/bar",
@@ -97,7 +98,7 @@ func TestValidateGlobPathOnlyOK(t *testing.T) {
 	for _, input := range testCases {
 		t.Run(input, func(t *testing.T) {
 			if errs := ValidatePathGlob(input); len(errs) > 0 {
-				t.Fatalf("path glob %q caused errors: %#v", input, errs)
+				t.Fatalf("path glob %q caused errors: %v", input, errs)
 			}
 		})
 	}
@@ -152,17 +153,17 @@ func TestValidateGlobSyntaxError(t *testing.T) {
 		},
 		{
 			what:     "newline in pattern",
-			input:    "\n",
+			input:    "foo\nbar",
 			expected: "newline cannot be contained",
 		},
 		{
 			what:     `newline with \r in pattern`,
-			input:    "\r",
+			input:    "foo\rbar",
 			expected: `'\r'`,
 		},
 		{
 			what:     `newline with \r\n in pattern`,
-			input:    "\r\n",
+			input:    "foo\r\nbar",
 			expected: `'\n'`,
 		},
 		{
@@ -295,7 +296,7 @@ func TestValidateGlobGitRefNameInvalidCharacter(t *testing.T) {
 		{
 			what:     "escaped non-special character",
 			input:    `\d`,
-			expected: "only special characters [, ?, +, *, \\ ! can be escaped with \\",
+			expected: "only special characters [, ?, +, *, \\, ! can be escaped with \\",
 		},
 		{
 			what:  "prohibited characters for ref names",
@@ -314,11 +315,11 @@ func TestValidateGlobGitRefNameInvalidCharacter(t *testing.T) {
 			expectedAll: []string{
 				"ref name must not start with /",
 				"ref name cannot contain spaces, ~, ^, :, [, ?, *",
-				"only special characters [, ?, +, *, \\ ! can be escaped with \\",
-				"only special characters [, ?, +, *, \\ ! can be escaped with \\",
-				"only special characters [, ?, +, *, \\ ! can be escaped with \\",
-				"only special characters [, ?, +, *, \\ ! can be escaped with \\",
-				"only special characters [, ?, +, *, \\ ! can be escaped with \\",
+				"only special characters [, ?, +, *, \\, ! can be escaped with \\",
+				"only special characters [, ?, +, *, \\, ! can be escaped with \\",
+				"only special characters [, ?, +, *, \\, ! can be escaped with \\",
+				"only special characters [, ?, +, *, \\, ! can be escaped with \\",
+				"only special characters [, ?, +, *, \\, ! can be escaped with \\",
 				"ref name must not end with / and .",
 			},
 		},
@@ -377,7 +378,7 @@ func TestValidateGlobErrorColumn(t *testing.T) {
 			errs := ValidateRefGlob(tc.input)
 
 			if len(errs) != 1 {
-				t.Fatalf("wanted 1 error from %q but got %d errors: %#v", tc.input, len(errs), errs)
+				t.Fatalf("wanted 1 error from %q but got %d errors: %v", tc.input, len(errs), errs)
 			}
 
 			want, have := tc.col, errs[0].Column
@@ -411,3 +412,61 @@ func TestValidateGlobQuoteCharacterInErrorMessage(t *testing.T) {
 		})
 	}
 }
+
+func TestValidateInvalidPathGlobError(t *testing.T) {
+	tests := []struct {
+		what     string
+		input    string
+		expected string
+	}{
+		{
+			what:     "leading spaces",
+			input:    "   foo.txt",
+			expected: "leading and trailing spaces are not allowed in glob path",
+		},
+		{
+			what:     "trailing spaces",
+			input:    "foo.txt\n",
+			expected: "leading and trailing spaces are not allowed in glob path",
+		},
+		{
+			what:     "current directory .",
+			input:    ".",
+			expected: "'.' and '..' are not allowed in glob path",
+		},
+		{
+			what:     "parent directory ..",
+			input:    "..",
+			expected: "'.' and '..' are not allowed in glob path",
+		},
+		{
+			what:     "current directory . with !",
+			input:    "!.",
+			expected: "'.' and '..' are not allowed in glob path",
+		},
+		{
+			what:     "starts with .",
+			input:    "./foo.txt",
+			expected: "'.' and '..' are not allowed in glob path",
+		},
+		{
+			what:     "starts with ..",
+			input:    "../foo.txt",
+			expected: "'.' and '..' are not allowed in glob path",
+		},
+		{
+			what:     "starts with . and !",
+			input:    "!./foo.txt",
+			expected: "'.' and '..' are not allowed in glob path",
+		},
+	}
+
+	for _, tc := range tests {
+		t.Run(tc.what, func(t *testing.T) {
+			errs := ValidatePathGlob(tc.input)
+			if len(errs) != 1 {
+				t.Fatalf("wanted 1 error %q but got %d errors: %v", tc.expected, len(errs), errs)
+			}
+		})
+	}
+}
