@@ -19,9 +19,11 @@ const (
 	compatMacOS150L
 	compatMacOS150XL
 	compatMacOS260
+	compatMacOS260L
 	compatMacOS260XL
 	compatWindows2022
 	compatWindows2025
+	compatWindows2025VS2026
 	compatWindows11Arm
 )
 
@@ -30,6 +32,7 @@ var allGitHubHostedRunnerLabels = []string{
 	"windows-latest",
 	"windows-latest-8-cores",
 	"windows-2025",
+	"windows-2025-vs2026",
 	"windows-2022",
 	"windows-11-arm",
 	"ubuntu-slim",
@@ -45,6 +48,7 @@ var allGitHubHostedRunnerLabels = []string{
 	"macos-latest-xlarge",
 	"macos-latest-large",
 	"macos-26-xlarge",
+	"macos-26-large",
 	"macos-26",
 	"macos-15-intel",
 	"macos-15-xlarge",
@@ -84,6 +88,7 @@ var defaultRunnerOSCompats = map[string]runnerOSCompat{
 	"macos-latest-large":     compatMacOS150L,
 	"macos-latest":           compatMacOS150,
 	"macos-26-xlarge":        compatMacOS260XL,
+	"macos-26-large":         compatMacOS260L,
 	"macos-26":               compatMacOS260,
 	"macos-15-intel":         compatMacOS150Intel,
 	"macos-15-xlarge":        compatMacOS150XL,
@@ -95,11 +100,12 @@ var defaultRunnerOSCompats = map[string]runnerOSCompat{
 	"windows-latest":         compatWindows2022,
 	"windows-latest-8-cores": compatWindows2022,
 	"windows-2025":           compatWindows2025,
+	"windows-2025-vs2026":    compatWindows2025VS2026,
 	"windows-2022":           compatWindows2022,
 	"windows-11-arm":         compatWindows11Arm,
 	"linux":                  compatUbuntu2404 | compatUbuntu2204, // Note: "linux" does not always indicate Ubuntu. It might be Fedora or Arch or ...
-	"macos":                  compatMacOS260 | compatMacOS260XL | compatMacOS150 | compatMacOS150Intel | compatMacOS150L | compatMacOS150XL | compatMacOS140 | compatMacOS140L | compatMacOS140XL,
-	"windows":                compatWindows2025 | compatWindows2022 | compatWindows11Arm,
+	"macos":                  compatMacOS260 | compatMacOS260L | compatMacOS260XL | compatMacOS150 | compatMacOS150Intel | compatMacOS150L | compatMacOS150XL | compatMacOS140 | compatMacOS140L | compatMacOS140XL,
+	"windows":                compatWindows2025VS2026 | compatWindows2025 | compatWindows2022 | compatWindows11Arm,
 }
 
 // RuleRunnerLabel is a rule to check runner label like "ubuntu-latest". There are two types of
